@@ -29,6 +29,7 @@ from hspylib.modules.cli.application.version import Version
 from vault.__classpath__ import _Classpath
 from vault.core.vault import Vault
 from vault.core.vault_config import VaultConfig
+from vault.exception.exceptions import VaultExecutionException
 
 
 class Main(Application):
@@ -82,9 +83,9 @@ class Main(Application):
         signal.signal(signal.SIGINT, self._abort)
         signal.signal(signal.SIGTERM, self._abort)
         signal.signal(signal.SIGABRT, self._abort)
+        signal.signal(signal.SIGHUP, self._abort)
 
-        self._exec_application()
-        return 0
+        return self._exec_application()
 
     def _cleanup(self) -> None:
         """TODO"""
@@ -98,9 +99,9 @@ class Main(Application):
         self._cleanup()
         self.exit(signum, frame)
 
-    def _exec_application(self, ) -> None:
+    def _exec_application(self, ) -> int:
         """Execute the specified vault operation"""
-        op = self.get_arg('operation')
+        ret_val, op = 0, self.get_arg('operation')
         try:
             if self.vault.open():
                 if op == 'add':
@@ -114,11 +115,16 @@ class Main(Application):
                 elif op == 'list':
                     self.vault.list(self.get_arg('filter'))
                 else:
+                    ret_val = 1
                     syserr(f'### Invalid operation: {op}')
                     self.usage(1)
+        except Exception as err:
+            raise VaultExecutionException(f"Failed to execute Vault => {err}") from err
         finally:
             self.vault.close()
 
+        return ret_val
+
 
 if __name__ == "__main__":
     # Application entry point
